/*
NOME: 0020_DENSTPO_USR_INVENTFILIAL.SQL

DESCRIO: Procedimento para exportao da posio de estoque e ajustes de estoque.

CRIAO: 29/08/2008 - Fabrcio Marcelo da Silva

@C:\Web_503\Xdb\Src\Cli\DEN\Sql\0020_DENSTPO_USR_INVENTFILIAL.SQL

RAISE_APPLICATION_ERROR(-20501, '' , TRUE);
*/

CREATE OR REPLACE PROCEDURE USR_INVENTFILIAL(
     P_CDFILIAL IN FILIAL.CDFILIAL%TYPE,
     P_DTINVENT IN LANCTOESTOQ.DTLANCESTQ%TYPE)
AS
   V_DTGRV         DATE;
   V_HRGRV         VARCHAR2(04);
BEGIN
   V_DTGRV := NULL;
   V_HRGRV := NULL;

   /* Retorna data e hora de exportao */
   BEGIN
      SELECT TO_DATE(SYSDATE), TO_CHAR(SYSDATE,'HH24MI')
      INTO V_DTGRV, V_HRGRV
      FROM DUAL;
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         V_DTGRV := NULL;
         V_HRGRV := NULL;
   END;

   /* Exclui toda posio de estoque da filial para a data informada */
   DELETE FROM USR_ZWI
   WHERE WI_CDFILIAL = P_CDFILIAL
     AND WI_DTPOSI = TO_DATE(P_DTINVENT);

   /* Verificao dos lanamentos de estoque referente a posio de estoque */
   FOR C_MOVESTO IN (SELECT SUBSTR(F.CDGRUPFILI,7,2) AS EMPRESA, SUBSTR(F.CDGRUPFILI,9,2) AS FILIAL,
                            B.CDFILIAL, A.CDPRODINTE, TO_DATE(P_DTINVENT) AS DTPOSIESTQ, B.CDALMOXARIFE,
                            B.CDLOCALESTOQ, B.QTESTOQDIA, B.VRESTOQDIA, A.NMPRODUTO,
                            B.NRLOTEESTQ, B.NRSUBLOTE, L.DTVALILOTE
                       FROM POSESTDIA B, PRODUTO A, LOTE L,
                            (SELECT MIN(CDGRUPFILI) AS CDGRUPFILI
                               FROM FILGRUPFILI
                              WHERE CDFILIAL = P_CDFILIAL) F
                      WHERE B.CDFILIAL   = P_CDFILIAL
                        AND B.QTESTOQDIA <> 0
                        AND B.CDPRODUTO  = A.CDPRODUTO
                        AND B.DTPOSIESTQ = (SELECT MAX(P.DTPOSIESTQ)
                                               FROM POSESTDIA P
                                              WHERE P.CDFILIAL     = P_CDFILIAL
                                                AND P.CDPRODUTO    = B.CDPRODUTO
                                                AND P.CDALMOXARIFE = B.CDALMOXARIFE
                                                AND P.CDLOCALESTOQ = B.CDLOCALESTOQ
                                                AND P.NRLOTEESTQ   = B.NRLOTEESTQ
                                                AND P.NRSUBLOTE    = B.NRSUBLOTE
                                                AND P.DTPOSIESTQ   <= P_DTINVENT)
                        AND B.CDFILIAL   = L.CDFILIAL (+)
                        AND B.NRLOTEESTQ = L.NRLOTEESTQ (+)
                        AND B.NRSUBLOTE  = L.NRSUBLOTE (+)
                        AND B.CDPRODUTO  = L.CDPRODUTO (+))
   LOOP
      /* Insere dados referente a posio de estoque */
      INSERT INTO USR_ZWI
         (WI_CDFILIAL, WI_FILIAL, WI_CC, WI_COD, WI_DTPOSI, WI_ALMOX, WI_LOCAL, WI_QUANT,
          WI_CUSTO, WI_DESC, WI_LOTECTL, WI_NUMLOTE, WI_DTVALID, WI_TPEDI,
          WI_DTGRV, WI_HRGRV)
      VALUES
         (C_MOVESTO.CDFILIAL, C_MOVESTO.FILIAL, C_MOVESTO.CDFILIAL, SUBSTR(C_MOVESTO.CDPRODINTE,1,15), C_MOVESTO.DTPOSIESTQ,
          SUBSTR(C_MOVESTO.CDALMOXARIFE,1,6), SUBSTR(C_MOVESTO.CDLOCALESTOQ,1,6), C_MOVESTO.QTESTOQDIA, C_MOVESTO.VRESTOQDIA,
          SUBSTR(C_MOVESTO.NMPRODUTO,1,35), SUBSTR(C_MOVESTO.NRLOTEESTQ,1,10), SUBSTR(C_MOVESTO.NRSUBLOTE,1,6), C_MOVESTO.DTVALILOTE,
          '1', V_DTGRV, V_HRGRV);
   END LOOP;
   COMMIT;
END;
/
