import { TekGrid } from '@zeedhi/teknisa-components-common';
import { Metadata, Http } from '@zeedhi/core';
import {
    LoadingService, TextInput, IGridEvent, Select, Modal, ModalService, Form, DialogService,
} from '@zeedhi/common';
import { Utilities } from '@/util/Utilities';

export class Sm00052001DescontoMaximoServicoOperadorController {
    private headerFooterModal!: Modal;

    private modalEditarServico!: Modal;

    public currentRow: any = {};

    get getNomeOperador() {
        return this.currentRow.NMOPERADOR;
    }

    public setFiltroGridServico(nrparcnegocio : number) {
        const component = Metadata.getInstance<TekGrid>('basic-tek-grid-modal-editar-servico');
        component.datasource.setFilter({
            NRPARCNEGOCIO: nrparcnegocio,
        });
    }
    
    public async abrirModalServico({ row } : any) {
        await this.exibirModalServico();
        this.currentRow = row;
        this.setFiltroGridServico(row.NRPARCNEGOCIO);
    }

    public addRowServico() {
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-modal-editar-servico');
        grid.addNewRow({ NRSEQDESC: 0, NRPARCNEGOCIO: this.currentRow.NRPARCNEGOCIO }, 'start');
    }

    public async exibirModalServico() {
        this.modalEditarServico?.destroy();
        this.modalEditarServico = await ModalService.createFromJson('sm_00058_000_configuracoes_proposta/sm_00052_000_desconto_maximo_servico/modal/sm_00052_001_editar_servico', true);
        this.modalEditarServico.show();
    }

    public fecharModalServico() {
        this.modalEditarServico.hide();
        this.modalEditarServico?.destroy();
    }

    public async exibirModalInsercaoDescontoMaximoServico() {
        this.modalEditarServico?.destroy();
        this.headerFooterModal = await ModalService.createFromJson('sm_00058_000_configuracoes_proposta/sm_00052_000_desconto_maximo_servico/modal/sm_00052_001_inserir-desconto-maximo-servico', true);
        this.headerFooterModal.show();
    }

    public fecharModalInsercaoDescontoMaximoServico() {
        this.headerFooterModal.hide();
        this.headerFooterModal?.destroy();
    }

    public async abrirModoInsercaoDescontoMaximoServico() {
        await this.exibirModalInsercaoDescontoMaximoServico();
    }

    public afterModify() {
        Metadata.getInstance<TekGrid>('basic-tek-grid-modal-operador').datasource.get();
    }

    public insertServico({ event, component } : any) {
        event!.preventDefault();
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-modal-editar-servico');
        const editedrows = grid.getEditedRows();

        if (component.isGridValid()) {
            LoadingService.show();
            Http.post('/saveDescMaxServicoOperador', editedrows).then(() => {
                grid.cancelEditedRows();
                grid.reload();
                Utilities.showSuccessMessage();
                grid.datasource.get();
            }).catch((error) => {
                if (error.response.data.error === 'ERRO') {
                    Utilities.showDialogMessage('error', 'Operação bloqueada!', 'Já existe um desconto cadastrado para o Serviço e Operador informado.');
                } else {
                    Utilities.showErrorMessage(error);
                }
            }).finally(() => {
                LoadingService.hide();
            });
        } else {
            Utilities.alertMessage('Preencha todos os campos obrigatórios', 'error');
        }
    }

    public insertDescMaxServicoModalOperador({ event } : IGridEvent) {
        event!.preventDefault();
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-operador');
        const form = Metadata.getInstance<Form>('form');

        if (Utilities.validateForm(form)) {
            LoadingService.show();
            Http.post('/saveDescMaxServicoOperador', [{
                NRPARCNEGOCIO: Metadata.getInstance<TextInput>('NRPARCNEGOCIO').value,
                NRSEQDESC: Metadata.getInstance<TextInput>('NRSEQDESC').value,
                CDSERVORCA: Metadata.getInstance<Select>('CDSERVORCA').value,
                VRPERCDESC: Metadata.getInstance<TextInput>('VRPERCDESC').value,
            }]).then(() => {
                this.fecharModalInsercaoDescontoMaximoServico();
                grid.datasource.get();
                Utilities.showSuccessMessage();
            }).catch((error) => {
                if (error.response.data.error === 'ERRO') {
                    Utilities.showDialogMessage('error', 'Operação bloqueada!', 'Já existe um desconto cadastrado para o Serviço e Operador informado.');
                } else {
                    Utilities.showErrorMessage(error);
                }
            }).finally(() => {
                LoadingService.hide();
            });
        }
    }

    public showConfirmDeleteMessage({ event }: any) {
        event!.preventDefault();
        DialogService.show({
            name: 'buttons-dialog',
            type: 'warning',
            title: 'Excluir Registro',
            text: 'Deseja realmente excluir todos os registros selecionados?',
            buttons: [
                {
                    name: 'NAO',
                    component: 'ZdButton',
                    label: 'Não',
                    outline: true,
                    events: {
                        click: () => {
                            DialogService.hide();
                        },
                    },
                },
                {
                    name: 'SIM',
                    component: 'ZdButton',
                    label: 'Sim',
                    events: {
                        click: () => {
                            this.deleteDescMaxServicoModalServico();
                            DialogService.hide();
                        },
                    },
                },
            ],
        });
    }

    public deleteDescMaxServicoModalServico() {
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-modal-editar-servico');
        const gridOperador = Metadata.getInstance<TekGrid>('basic-tek-grid-operador');
        LoadingService.show();
        Http.post('/deleteDescMaxServicoModalServico', grid.selectedRows).then(() => {
            grid.selectedRows = [];
            grid.cancelEditedRows();
            grid.reload();
            gridOperador.reload();
            Utilities.showSuccessMessage();
        }).catch((error) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
        });
    }
}
